@@ -13,7 +13,7 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -172,10 +172,10 @@ sub writeEDIDTable {
     my $err;
 
     $io->writeKSV( 0x40, 0x81 );    # Disable HDCP 1.1
-    $io->writeKSV( 0x74, 0x00 );    # reset ksv controller
+    $io->writeKSV( 0x74, 0x00 );    # disable internal EDID
 
     my $count = @edid;
-    printf( "Write edid data %d bytes\n", count );
+    printf( "Write edid data %d bytes\n", $count );
 
     for ( my $i = 0 ; $i < $count ; $i++ ) {
 
@@ -190,8 +190,7 @@ sub writeEDIDTable {
         }
     }
 
-    $io->writeKSV( 0x74, 0x01 );    # KSV controller is out of reset
-
+    $io->writeKSV( 0x74, 0x01 );    # enable internal EDID
     $io->writeIO( 0x15, 0xBE );
 }
 
@@ -212,8 +211,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.05"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.05" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.05"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.05" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.06"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.06" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.06"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.06" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -221,7 +220,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
